Class: Aws::Athena::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Athena::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-athena/client.rb,
sig/client.rbs
Overview
An API client for Athena. To construct a client, you need to configure a :region and :credentials.
client = Aws::Athena::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetNamedQueryResponseSuccess, _BatchGetPreparedStatementResponseSuccess, _BatchGetQueryExecutionResponseSuccess, _CancelCapacityReservationResponseSuccess, _CreateCapacityReservationResponseSuccess, _CreateDataCatalogResponseSuccess, _CreateNamedQueryResponseSuccess, _CreateNotebookResponseSuccess, _CreatePreparedStatementResponseSuccess, _CreatePresignedNotebookUrlResponseSuccess, _CreateWorkGroupResponseSuccess, _DeleteCapacityReservationResponseSuccess, _DeleteDataCatalogResponseSuccess, _DeleteNamedQueryResponseSuccess, _DeleteNotebookResponseSuccess, _DeletePreparedStatementResponseSuccess, _DeleteWorkGroupResponseSuccess, _ExportNotebookResponseSuccess, _GetCalculationExecutionCodeResponseSuccess, _GetCalculationExecutionResponseSuccess, _GetCalculationExecutionStatusResponseSuccess, _GetCapacityAssignmentConfigurationResponseSuccess, _GetCapacityReservationResponseSuccess, _GetDataCatalogResponseSuccess, _GetDatabaseResponseSuccess, _GetNamedQueryResponseSuccess, _GetNotebookMetadataResponseSuccess, _GetPreparedStatementResponseSuccess, _GetQueryExecutionResponseSuccess, _GetQueryResultsResponseSuccess, _GetQueryRuntimeStatisticsResponseSuccess, _GetResourceDashboardResponseSuccess, _GetSessionEndpointResponseSuccess, _GetSessionResponseSuccess, _GetSessionStatusResponseSuccess, _GetTableMetadataResponseSuccess, _GetWorkGroupResponseSuccess, _ImportNotebookResponseSuccess, _ListApplicationDPUSizesResponseSuccess, _ListCalculationExecutionsResponseSuccess, _ListCapacityReservationsResponseSuccess, _ListDataCatalogsResponseSuccess, _ListDatabasesResponseSuccess, _ListEngineVersionsResponseSuccess, _ListExecutorsResponseSuccess, _ListNamedQueriesResponseSuccess, _ListNotebookMetadataResponseSuccess, _ListNotebookSessionsResponseSuccess, _ListPreparedStatementsResponseSuccess, _ListQueryExecutionsResponseSuccess, _ListSessionsResponseSuccess, _ListTableMetadataResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkGroupsResponseSuccess, _PutCapacityAssignmentConfigurationResponseSuccess, _StartCalculationExecutionResponseSuccess, _StartQueryExecutionResponseSuccess, _StartSessionResponseSuccess, _StopCalculationExecutionResponseSuccess, _StopQueryExecutionResponseSuccess, _TagResourceResponseSuccess, _TerminateSessionResponseSuccess, _UntagResourceResponseSuccess, _UpdateCapacityReservationResponseSuccess, _UpdateDataCatalogResponseSuccess, _UpdateNamedQueryResponseSuccess, _UpdateNotebookMetadataResponseSuccess, _UpdateNotebookResponseSuccess, _UpdatePreparedStatementResponseSuccess, _UpdateWorkGroupResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_named_query(params = {}) ⇒ Types::BatchGetNamedQueryOutput
Returns the details of a single named query or a list of up to 50 queries, which you provide as an array of query ID strings.
-
#batch_get_prepared_statement(params = {}) ⇒ Types::BatchGetPreparedStatementOutput
Returns the details of a single prepared statement or a list of up to 256 prepared statements for the array of prepared statement names that you provide.
-
#batch_get_query_execution(params = {}) ⇒ Types::BatchGetQueryExecutionOutput
Returns the details of a single query execution or a list of up to 50 query executions, which you provide as an array of query execution ID strings.
-
#cancel_capacity_reservation(params = {}) ⇒ Struct
Cancels the capacity reservation with the specified name.
-
#create_capacity_reservation(params = {}) ⇒ Struct
Creates a capacity reservation with the specified name and number of requested data processing units.
-
#create_data_catalog(params = {}) ⇒ Types::CreateDataCatalogOutput
Creates (registers) a data catalog with the specified name and properties.
-
#create_named_query(params = {}) ⇒ Types::CreateNamedQueryOutput
Creates a named query in the specified workgroup.
-
#create_notebook(params = {}) ⇒ Types::CreateNotebookOutput
Creates an empty
ipynbfile in the specified Apache Spark enabled workgroup. -
#create_prepared_statement(params = {}) ⇒ Struct
Creates a prepared statement for use with SQL queries in Athena.
-
#create_presigned_notebook_url(params = {}) ⇒ Types::CreatePresignedNotebookUrlResponse
Gets an authentication token and the URL at which the notebook can be accessed.
-
#create_work_group(params = {}) ⇒ Struct
Creates a workgroup with the specified name.
-
#delete_capacity_reservation(params = {}) ⇒ Struct
Deletes a cancelled capacity reservation.
-
#delete_data_catalog(params = {}) ⇒ Types::DeleteDataCatalogOutput
Deletes a data catalog.
-
#delete_named_query(params = {}) ⇒ Struct
Deletes the named query if you have access to the workgroup in which the query was saved.
-
#delete_notebook(params = {}) ⇒ Struct
Deletes the specified notebook.
-
#delete_prepared_statement(params = {}) ⇒ Struct
Deletes the prepared statement with the specified name from the specified workgroup.
-
#delete_work_group(params = {}) ⇒ Struct
Deletes the workgroup with the specified name.
-
#export_notebook(params = {}) ⇒ Types::ExportNotebookOutput
Exports the specified notebook and its metadata.
-
#get_calculation_execution(params = {}) ⇒ Types::GetCalculationExecutionResponse
Describes a previously submitted calculation execution.
-
#get_calculation_execution_code(params = {}) ⇒ Types::GetCalculationExecutionCodeResponse
Retrieves the unencrypted code that was executed for the calculation.
-
#get_calculation_execution_status(params = {}) ⇒ Types::GetCalculationExecutionStatusResponse
Gets the status of a current calculation.
-
#get_capacity_assignment_configuration(params = {}) ⇒ Types::GetCapacityAssignmentConfigurationOutput
Gets the capacity assignment configuration for a capacity reservation, if one exists.
-
#get_capacity_reservation(params = {}) ⇒ Types::GetCapacityReservationOutput
Returns information about the capacity reservation with the specified name.
-
#get_data_catalog(params = {}) ⇒ Types::GetDataCatalogOutput
Returns the specified data catalog.
-
#get_database(params = {}) ⇒ Types::GetDatabaseOutput
Returns a database object for the specified database and data catalog.
-
#get_named_query(params = {}) ⇒ Types::GetNamedQueryOutput
Returns information about a single query.
-
#get_notebook_metadata(params = {}) ⇒ Types::GetNotebookMetadataOutput
Retrieves notebook metadata for the specified notebook ID.
-
#get_prepared_statement(params = {}) ⇒ Types::GetPreparedStatementOutput
Retrieves the prepared statement with the specified name from the specified workgroup.
-
#get_query_execution(params = {}) ⇒ Types::GetQueryExecutionOutput
Returns information about a single execution of a query if you have access to the workgroup in which the query ran.
-
#get_query_results(params = {}) ⇒ Types::GetQueryResultsOutput
Streams the results of a single query execution specified by
QueryExecutionIdfrom the Athena query results location in Amazon S3. -
#get_query_runtime_statistics(params = {}) ⇒ Types::GetQueryRuntimeStatisticsOutput
Returns query execution runtime statistics related to a single execution of a query if you have access to the workgroup in which the query ran.
-
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Gets the Live UI/Persistence UI for a session.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets the full details of a previously created session, including the session status and configuration.
-
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Gets a connection endpoint and authentication token for a given session Id.
-
#get_session_status(params = {}) ⇒ Types::GetSessionStatusResponse
Gets the current status of a session.
-
#get_table_metadata(params = {}) ⇒ Types::GetTableMetadataOutput
Returns table metadata for the specified catalog, database, and table.
-
#get_work_group(params = {}) ⇒ Types::GetWorkGroupOutput
Returns information about the workgroup with the specified name.
-
#import_notebook(params = {}) ⇒ Types::ImportNotebookOutput
Imports a single
ipynbfile to a Spark enabled workgroup. -
#list_application_dpu_sizes(params = {}) ⇒ Types::ListApplicationDPUSizesOutput
Returns the supported DPU sizes for the supported application runtimes (for example,
Athena notebook version 1). -
#list_calculation_executions(params = {}) ⇒ Types::ListCalculationExecutionsResponse
Lists the calculations that have been submitted to a session in descending order.
-
#list_capacity_reservations(params = {}) ⇒ Types::ListCapacityReservationsOutput
Lists the capacity reservations for the current account.
-
#list_data_catalogs(params = {}) ⇒ Types::ListDataCatalogsOutput
Lists the data catalogs in the current Amazon Web Services account.
-
#list_databases(params = {}) ⇒ Types::ListDatabasesOutput
Lists the databases in the specified data catalog.
-
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsOutput
Returns a list of engine versions that are available to choose from, including the Auto option.
-
#list_executors(params = {}) ⇒ Types::ListExecutorsResponse
Lists, in descending order, the executors that joined a session.
-
#list_named_queries(params = {}) ⇒ Types::ListNamedQueriesOutput
Provides a list of available query IDs only for queries saved in the specified workgroup.
-
#list_notebook_metadata(params = {}) ⇒ Types::ListNotebookMetadataOutput
Displays the notebook files for the specified workgroup in paginated format.
-
#list_notebook_sessions(params = {}) ⇒ Types::ListNotebookSessionsResponse
Lists, in descending order, the sessions that have been created in a notebook that are in an active state like
CREATING,CREATED,IDLEorBUSY. -
#list_prepared_statements(params = {}) ⇒ Types::ListPreparedStatementsOutput
Lists the prepared statements in the specified workgroup.
-
#list_query_executions(params = {}) ⇒ Types::ListQueryExecutionsOutput
Provides a list of available query execution IDs for the queries in the specified workgroup.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists the sessions in a workgroup that are in an active state like
CREATING,CREATED,IDLE, orBUSY. -
#list_table_metadata(params = {}) ⇒ Types::ListTableMetadataOutput
Lists the metadata for the tables in the specified data catalog database.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with an Athena resource.
-
#list_work_groups(params = {}) ⇒ Types::ListWorkGroupsOutput
Lists available workgroups for the account.
-
#put_capacity_assignment_configuration(params = {}) ⇒ Struct
Puts a new capacity assignment configuration for a specified capacity reservation.
-
#start_calculation_execution(params = {}) ⇒ Types::StartCalculationExecutionResponse
Submits calculations for execution within a session.
-
#start_query_execution(params = {}) ⇒ Types::StartQueryExecutionOutput
Runs the SQL query statements contained in the
Query. -
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates a session for running calculations within a workgroup.
-
#stop_calculation_execution(params = {}) ⇒ Types::StopCalculationExecutionResponse
Requests the cancellation of a calculation.
-
#stop_query_execution(params = {}) ⇒ Struct
Stops a query execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to an Athena resource.
-
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates an active session.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an Athena resource.
-
#update_capacity_reservation(params = {}) ⇒ Struct
Updates the number of requested data processing units for the capacity reservation with the specified name.
-
#update_data_catalog(params = {}) ⇒ Struct
Updates the data catalog that has the specified name.
-
#update_named_query(params = {}) ⇒ Struct
Updates a NamedQuery object.
-
#update_notebook(params = {}) ⇒ Struct
Updates the contents of a Spark notebook.
-
#update_notebook_metadata(params = {}) ⇒ Struct
Updates the metadata for a notebook.
-
#update_prepared_statement(params = {}) ⇒ Struct
Updates a prepared statement.
-
#update_work_group(params = {}) ⇒ Struct
Updates the workgroup with the specified name.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-athena/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4145 4146 4147 |
# File 'lib/aws-sdk-athena/client.rb', line 4145 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4148 4149 4150 |
# File 'lib/aws-sdk-athena/client.rb', line 4148 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_named_query(params = {}) ⇒ Types::BatchGetNamedQueryOutput
Returns the details of a single named query or a list of up to 50 queries, which you provide as an array of query ID strings. Requires you to have access to the workgroup in which the queries were saved. Use ListNamedQueriesInput to get the list of named query IDs in the specified workgroup. If information could not be retrieved for a submitted query ID, information about the query ID submitted is listed under UnprocessedNamedQueryId. Named queries differ from executed queries. Use BatchGetQueryExecutionInput to get details about each unique query execution, and ListQueryExecutionsInput to get a list of query execution IDs.
88 |
# File 'sig/client.rbs', line 88
def batch_get_named_query: (
|
#batch_get_prepared_statement(params = {}) ⇒ Types::BatchGetPreparedStatementOutput
Returns the details of a single prepared statement or a list of up to
256 prepared statements for the array of prepared statement names that
you provide. Requires you to have access to the workgroup to which the
prepared statements belong. If a prepared statement cannot be
retrieved for the name specified, the statement is listed in
UnprocessedPreparedStatementNames.
99 |
# File 'sig/client.rbs', line 99
def batch_get_prepared_statement: (
|
#batch_get_query_execution(params = {}) ⇒ Types::BatchGetQueryExecutionOutput
Returns the details of a single query execution or a list of up to 50 query executions, which you provide as an array of query execution ID strings. Requires you to have access to the workgroup in which the queries ran. To get a list of query execution IDs, use ListQueryExecutionsInput$WorkGroup. Query executions differ from named (saved) queries. Use BatchGetNamedQueryInput to get details about named queries.
111 |
# File 'sig/client.rbs', line 111
def batch_get_query_execution: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 |
# File 'lib/aws-sdk-athena/client.rb', line 4118 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Athena') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-athena' context[:gem_version] = '1.123.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_capacity_reservation(params = {}) ⇒ Struct
Cancels the capacity reservation with the specified name. Cancelled reservations remain in your account and will be deleted 45 days after cancellation. During the 45 days, you cannot re-purpose or reuse a reservation that has been cancelled, but you can refer to its tags and view it for historical reference.
120 |
# File 'sig/client.rbs', line 120
def cancel_capacity_reservation: (
|
#create_capacity_reservation(params = {}) ⇒ Struct
Creates a capacity reservation with the specified name and number of requested data processing units.
129 |
# File 'sig/client.rbs', line 129
def create_capacity_reservation: (
|
#create_data_catalog(params = {}) ⇒ Types::CreateDataCatalogOutput
Creates (registers) a data catalog with the specified name and properties. Catalogs created are visible to all users of the same Amazon Web Services account.
For a FEDERATED catalog, this API operation creates the following
resources.
-
CFN Stack Name with a maximum length of 128 characters and prefix
athenafederatedcatalog-CATALOG_NAME_SANITIZEDwith length 23 characters. -
Lambda Function Name with a maximum length of 64 characters and prefix
athenafederatedcatalog_CATALOG_NAME_SANITIZEDwith length 23 characters. -
Glue Connection Name with a maximum length of 255 characters and a prefix
athenafederatedcatalog_CATALOG_NAME_SANITIZEDwith length 23 characters.
146 |
# File 'sig/client.rbs', line 146
def create_data_catalog: (
|
#create_named_query(params = {}) ⇒ Types::CreateNamedQueryOutput
Creates a named query in the specified workgroup. Requires that you have access to the workgroup.
165 |
# File 'sig/client.rbs', line 165
def create_named_query: (
|
#create_notebook(params = {}) ⇒ Types::CreateNotebookOutput
Creates an empty ipynb file in the specified Apache Spark enabled
workgroup. Throws an error if a file in the workgroup with the same
name already exists.
180 |
# File 'sig/client.rbs', line 180
def create_notebook: (
|
#create_prepared_statement(params = {}) ⇒ Struct
Creates a prepared statement for use with SQL queries in Athena.
191 |
# File 'sig/client.rbs', line 191
def create_prepared_statement: (
|
#create_presigned_notebook_url(params = {}) ⇒ Types::CreatePresignedNotebookUrlResponse
Gets an authentication token and the URL at which the notebook can be
accessed. During programmatic access, CreatePresignedNotebookUrl
must be called every 10 minutes to refresh the authentication token.
For information about granting programmatic access, see Grant
programmatic access.
206 |
# File 'sig/client.rbs', line 206
def create_presigned_notebook_url: (
|
#create_work_group(params = {}) ⇒ Struct
Creates a workgroup with the specified name. A workgroup can be an Apache Spark enabled workgroup or an Athena SQL workgroup.
215 |
# File 'sig/client.rbs', line 215
def create_work_group: (
|
#delete_capacity_reservation(params = {}) ⇒ Struct
Deletes a cancelled capacity reservation. A reservation must be
cancelled before it can be deleted. A deleted reservation is
immediately removed from your account and can no longer be referenced,
including by its ARN. A deleted reservation cannot be called by
GetCapacityReservation, and deleted reservations do not appear in
the output of ListCapacityReservations.
265 |
# File 'sig/client.rbs', line 265
def delete_capacity_reservation: (
|
#delete_data_catalog(params = {}) ⇒ Types::DeleteDataCatalogOutput
Deletes a data catalog.
275 |
# File 'sig/client.rbs', line 275
def delete_data_catalog: (
|
#delete_named_query(params = {}) ⇒ Struct
Deletes the named query if you have access to the workgroup in which the query was saved.
285 |
# File 'sig/client.rbs', line 285
def delete_named_query: (
|
#delete_notebook(params = {}) ⇒ Struct
Deletes the specified notebook.
294 |
# File 'sig/client.rbs', line 294
def delete_notebook: (
|
#delete_prepared_statement(params = {}) ⇒ Struct
Deletes the prepared statement with the specified name from the specified workgroup.
303 |
# File 'sig/client.rbs', line 303
def delete_prepared_statement: (
|
#delete_work_group(params = {}) ⇒ Struct
Deletes the workgroup with the specified name. The primary workgroup cannot be deleted.
313 |
# File 'sig/client.rbs', line 313
def delete_work_group: (
|
#export_notebook(params = {}) ⇒ Types::ExportNotebookOutput
Exports the specified notebook and its metadata.
325 |
# File 'sig/client.rbs', line 325
def export_notebook: (
|
#get_calculation_execution(params = {}) ⇒ Types::GetCalculationExecutionResponse
Describes a previously submitted calculation execution.
341 |
# File 'sig/client.rbs', line 341
def get_calculation_execution: (
|
#get_calculation_execution_code(params = {}) ⇒ Types::GetCalculationExecutionCodeResponse
Retrieves the unencrypted code that was executed for the calculation.
351 |
# File 'sig/client.rbs', line 351
def get_calculation_execution_code: (
|
#get_calculation_execution_status(params = {}) ⇒ Types::GetCalculationExecutionStatusResponse
Gets the status of a current calculation.
362 |
# File 'sig/client.rbs', line 362
def get_calculation_execution_status: (
|
#get_capacity_assignment_configuration(params = {}) ⇒ Types::GetCapacityAssignmentConfigurationOutput
Gets the capacity assignment configuration for a capacity reservation, if one exists.
372 |
# File 'sig/client.rbs', line 372
def get_capacity_assignment_configuration: (
|
#get_capacity_reservation(params = {}) ⇒ Types::GetCapacityReservationOutput
Returns information about the capacity reservation with the specified name.
382 |
# File 'sig/client.rbs', line 382
def get_capacity_reservation: (
|
#get_data_catalog(params = {}) ⇒ Types::GetDataCatalogOutput
Returns the specified data catalog.
392 |
# File 'sig/client.rbs', line 392
def get_data_catalog: (
|
#get_database(params = {}) ⇒ Types::GetDatabaseOutput
Returns a database object for the specified database and data catalog.
403 |
# File 'sig/client.rbs', line 403
def get_database: (
|
#get_named_query(params = {}) ⇒ Types::GetNamedQueryOutput
Returns information about a single query. Requires that you have access to the workgroup in which the query was saved.
415 |
# File 'sig/client.rbs', line 415
def get_named_query: (
|
#get_notebook_metadata(params = {}) ⇒ Types::GetNotebookMetadataOutput
Retrieves notebook metadata for the specified notebook ID.
425 |
# File 'sig/client.rbs', line 425
def get_notebook_metadata: (
|
#get_prepared_statement(params = {}) ⇒ Types::GetPreparedStatementOutput
Retrieves the prepared statement with the specified name from the specified workgroup.
435 |
# File 'sig/client.rbs', line 435
def get_prepared_statement: (
|
#get_query_execution(params = {}) ⇒ Types::GetQueryExecutionOutput
Returns information about a single execution of a query if you have access to the workgroup in which the query ran. Each time a query executes, information about the query execution is saved with a unique ID.
446 |
# File 'sig/client.rbs', line 446
def get_query_execution: (
|
#get_query_results(params = {}) ⇒ Types::GetQueryResultsOutput
Streams the results of a single query execution specified by
QueryExecutionId from the Athena query results location in Amazon
S3. For more information, see Working with query results, recent
queries, and output files in the Amazon Athena User Guide. This
request does not execute the query but returns results. Use
StartQueryExecution to run a query.
To stream query results successfully, the IAM principal with
permission to call GetQueryResults also must have permissions to the
Amazon S3 GetObject action for the Athena query results location.
IAM principals with permission to the Amazon S3 GetObject action for
the query results location are able to retrieve query results from
Amazon S3 even if permission to the GetQueryResults action is
denied. To restrict user or role access, ensure that Amazon S3
permissions to the Athena query location are denied.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
458 |
# File 'sig/client.rbs', line 458
def get_query_results: (
|
#get_query_runtime_statistics(params = {}) ⇒ Types::GetQueryRuntimeStatisticsOutput
Returns query execution runtime statistics related to a single
execution of a query if you have access to the workgroup in which the
query ran. Statistics from the Timeline section of the response
object are available as soon as QueryExecutionStatus$State is in a
SUCCEEDED or FAILED state. The remaining non-timeline statistics in
the response (like stage-level input and output row count and data
size) are updated asynchronously and may not be available immediately
after a query completes or, in some cases, may not be returned. The
non-timeline statistics are also not included when a query has
row-level filters defined in Lake Formation.
471 |
# File 'sig/client.rbs', line 471
def get_query_runtime_statistics: (
|
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Gets the Live UI/Persistence UI for a session.
481 |
# File 'sig/client.rbs', line 481
def get_resource_dashboard: (
|
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets the full details of a previously created session, including the session status and configuration.
500 |
# File 'sig/client.rbs', line 500
def get_session: (
|
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Gets a connection endpoint and authentication token for a given session Id.
512 |
# File 'sig/client.rbs', line 512
def get_session_endpoint: (
|
#get_session_status(params = {}) ⇒ Types::GetSessionStatusResponse
Gets the current status of a session.
523 |
# File 'sig/client.rbs', line 523
def get_session_status: (
|
#get_table_metadata(params = {}) ⇒ Types::GetTableMetadataOutput
Returns table metadata for the specified catalog, database, and table.
533 |
# File 'sig/client.rbs', line 533
def get_table_metadata: (
|
#get_work_group(params = {}) ⇒ Types::GetWorkGroupOutput
Returns information about the workgroup with the specified name.
546 |
# File 'sig/client.rbs', line 546
def get_work_group: (
|
#import_notebook(params = {}) ⇒ Types::ImportNotebookOutput
Imports a single ipynb file to a Spark enabled workgroup. To import
the notebook, the request must specify a value for either Payload or
NoteBookS3LocationUri. If neither is specified or both are
specified, an InvalidRequestException occurs. The maximum file size
that can be imported is 10 megabytes. If an ipynb file with the same
name already exists in the workgroup, throws an error.
556 |
# File 'sig/client.rbs', line 556
def import_notebook: (
|
#list_application_dpu_sizes(params = {}) ⇒ Types::ListApplicationDPUSizesOutput
Returns the supported DPU sizes for the supported application runtimes
(for example, Athena notebook version 1).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
572 |
# File 'sig/client.rbs', line 572
def list_application_dpu_sizes: (
|
#list_calculation_executions(params = {}) ⇒ Types::ListCalculationExecutionsResponse
Lists the calculations that have been submitted to a session in descending order. Newer calculations are listed first; older calculations are listed later.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
584 |
# File 'sig/client.rbs', line 584
def list_calculation_executions: (
|
#list_capacity_reservations(params = {}) ⇒ Types::ListCapacityReservationsOutput
Lists the capacity reservations for the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
598 |
# File 'sig/client.rbs', line 598
def list_capacity_reservations: (
|
#list_data_catalogs(params = {}) ⇒ Types::ListDataCatalogsOutput
Lists the data catalogs in the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
610 |
# File 'sig/client.rbs', line 610
def list_data_catalogs: (
|
#list_databases(params = {}) ⇒ Types::ListDatabasesOutput
Lists the databases in the specified data catalog.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
623 |
# File 'sig/client.rbs', line 623
def list_databases: (
|
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsOutput
Returns a list of engine versions that are available to choose from, including the Auto option.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
637 |
# File 'sig/client.rbs', line 637
def list_engine_versions: (
|
#list_executors(params = {}) ⇒ Types::ListExecutorsResponse
Lists, in descending order, the executors that joined a session. Newer executors are listed first; older executors are listed later. The result can be optionally filtered by state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
650 |
# File 'sig/client.rbs', line 650
def list_executors: (
|
#list_named_queries(params = {}) ⇒ Types::ListNamedQueriesOutput
Provides a list of available query IDs only for queries saved in the specified workgroup. Requires that you have access to the specified workgroup. If a workgroup is not specified, lists the saved queries for the primary workgroup.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
664 |
# File 'sig/client.rbs', line 664
def list_named_queries: (
|
#list_notebook_metadata(params = {}) ⇒ Types::ListNotebookMetadataOutput
Displays the notebook files for the specified workgroup in paginated format.
677 |
# File 'sig/client.rbs', line 677
def list_notebook_metadata: (
|
#list_notebook_sessions(params = {}) ⇒ Types::ListNotebookSessionsResponse
Lists, in descending order, the sessions that have been created in a
notebook that are in an active state like CREATING, CREATED,
IDLE or BUSY. Newer sessions are listed first; older sessions are
listed later.
693 |
# File 'sig/client.rbs', line 693
def list_notebook_sessions: (
|
#list_prepared_statements(params = {}) ⇒ Types::ListPreparedStatementsOutput
Lists the prepared statements in the specified workgroup.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
706 |
# File 'sig/client.rbs', line 706
def list_prepared_statements: (
|
#list_query_executions(params = {}) ⇒ Types::ListQueryExecutionsOutput
Provides a list of available query execution IDs for the queries in the specified workgroup. Athena keeps a query history for 45 days. If a workgroup is not specified, returns a list of query execution IDs for the primary workgroup. Requires you to have access to the workgroup in which the queries ran.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
719 |
# File 'sig/client.rbs', line 719
def list_query_executions: (
|
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists the sessions in a workgroup that are in an active state like
CREATING, CREATED, IDLE, or BUSY. Newer sessions are listed
first; older sessions are listed later.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
732 |
# File 'sig/client.rbs', line 732
def list_sessions: (
|
#list_table_metadata(params = {}) ⇒ Types::ListTableMetadataOutput
Lists the metadata for the tables in the specified data catalog database.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
746 |
# File 'sig/client.rbs', line 746
def list_table_metadata: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with an Athena resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
762 |
# File 'sig/client.rbs', line 762
def list_tags_for_resource: (
|
#list_work_groups(params = {}) ⇒ Types::ListWorkGroupsOutput
Lists available workgroups for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
775 |
# File 'sig/client.rbs', line 775
def list_work_groups: (
|
#put_capacity_assignment_configuration(params = {}) ⇒ Struct
Puts a new capacity assignment configuration for a specified capacity reservation. If a capacity assignment configuration already exists for the capacity reservation, replaces the existing capacity assignment configuration.
785 |
# File 'sig/client.rbs', line 785
def put_capacity_assignment_configuration: (
|
#start_calculation_execution(params = {}) ⇒ Types::StartCalculationExecutionResponse
Submits calculations for execution within a session. You can supply the code to run as an inline code block within the request.
801 |
# File 'sig/client.rbs', line 801
def start_calculation_execution: (
|
#start_query_execution(params = {}) ⇒ Types::StartQueryExecutionOutput
Runs the SQL query statements contained in the Query. Requires you
to have access to the workgroup in which the query ran. Running
queries against an external catalog requires GetDataCatalog permission
to the catalog. For code samples using the Amazon Web Services SDK for
Java, see Examples and Code Samples in the Amazon Athena User
Guide.
817 |
# File 'sig/client.rbs', line 817
def start_query_execution: (
|
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates a session for running calculations within a workgroup. The
session is ready when it reaches an IDLE state.
843 |
# File 'sig/client.rbs', line 843
def start_session: (
|
#stop_calculation_execution(params = {}) ⇒ Types::StopCalculationExecutionResponse
Requests the cancellation of a calculation. A
StopCalculationExecution call on a calculation that is already in a
terminal state (for example, STOPPED, FAILED, or COMPLETED)
succeeds but has no effect.
867 |
# File 'sig/client.rbs', line 867
def stop_calculation_execution: (
|
#stop_query_execution(params = {}) ⇒ Struct
Stops a query execution. Requires you to have access to the workgroup in which the query ran.
876 |
# File 'sig/client.rbs', line 876
def stop_query_execution: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to an Athena resource. A tag is a label that you assign to a resource. Each tag consists of a key and an optional value, both of which you define. For example, you can use tags to categorize Athena workgroups, data catalogs, or capacity reservations by purpose, owner, or environment. Use a consistent set of tag keys to make it easier to search and filter the resources in your account. For best practices, see Tagging Best Practices. Tag keys can be from 1 to 128 UTF-8 Unicode characters, and tag values can be from 0 to 256 UTF-8 Unicode characters. Tags can use letters and numbers representable in UTF-8, and the following characters: + - = . _ : / @. Tag keys and values are case-sensitive. Tag keys must be unique per resource. If you specify more than one tag, separate them by commas.
885 |
# File 'sig/client.rbs', line 885
def tag_resource: (
|
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates an active session. A TerminateSession call on a session
that is already inactive (for example, in a FAILED, TERMINATED or
TERMINATING state) succeeds but has no effect. Calculations running
in the session when TerminateSession is called are forcefully
stopped, but may display as FAILED instead of STOPPED.
901 |
# File 'sig/client.rbs', line 901
def terminate_session: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an Athena resource.
910 |
# File 'sig/client.rbs', line 910
def untag_resource: (
|
#update_capacity_reservation(params = {}) ⇒ Struct
Updates the number of requested data processing units for the capacity reservation with the specified name.
920 |
# File 'sig/client.rbs', line 920
def update_capacity_reservation: (
|
#update_data_catalog(params = {}) ⇒ Struct
Updates the data catalog that has the specified name.
930 |
# File 'sig/client.rbs', line 930
def update_data_catalog: (
|
#update_named_query(params = {}) ⇒ Struct
Updates a NamedQuery object. The database or workgroup cannot be updated.
942 |
# File 'sig/client.rbs', line 942
def update_named_query: (
|
#update_notebook(params = {}) ⇒ Struct
Updates the contents of a Spark notebook.
954 |
# File 'sig/client.rbs', line 954
def update_notebook: (
|
#update_notebook_metadata(params = {}) ⇒ Struct
Updates the metadata for a notebook.
967 |
# File 'sig/client.rbs', line 967
def update_notebook_metadata: (
|
#update_prepared_statement(params = {}) ⇒ Struct
Updates a prepared statement.
978 |
# File 'sig/client.rbs', line 978
def update_prepared_statement: (
|
#update_work_group(params = {}) ⇒ Struct
Updates the workgroup with the specified name. The workgroup's name
cannot be changed. Only ConfigurationUpdates can be specified.
990 |
# File 'sig/client.rbs', line 990
def update_work_group: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4138 4139 4140 |
# File 'lib/aws-sdk-athena/client.rb', line 4138 def waiter_names [] end |