Class: Aws::Athena::Types::GetDatabaseInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-athena/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_nameString

The name of the data catalog that contains the database to return.



1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-athena/types.rb', line 1824

class GetDatabaseInput < Struct.new(
  :catalog_name,
  :database_name,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database to return.



1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-athena/types.rb', line 1824

class GetDatabaseInput < Struct.new(
  :catalog_name,
  :database_name,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end

#work_groupString

The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.



1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-athena/types.rb', line 1824

class GetDatabaseInput < Struct.new(
  :catalog_name,
  :database_name,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end