Class: Aws::Athena::Types::GetQueryResultsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-athena/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results (rows) to return in this request.



1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-athena/types.rb', line 1970

class GetQueryResultsInput < Struct.new(
  :query_execution_id,
  :next_token,
  :max_results,
  :query_result_type)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.



1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-athena/types.rb', line 1970

class GetQueryResultsInput < Struct.new(
  :query_execution_id,
  :next_token,
  :max_results,
  :query_result_type)
  SENSITIVE = []
  include Aws::Structure
end

#query_execution_idString

The unique ID of the query execution.



1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-athena/types.rb', line 1970

class GetQueryResultsInput < Struct.new(
  :query_execution_id,
  :next_token,
  :max_results,
  :query_result_type)
  SENSITIVE = []
  include Aws::Structure
end

#query_result_typeString

When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types ‘CREATE TABLE AS SELECT`, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.



1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/aws-sdk-athena/types.rb', line 1970

class GetQueryResultsInput < Struct.new(
  :query_execution_id,
  :next_token,
  :max_results,
  :query_result_type)
  SENSITIVE = []
  include Aws::Structure
end