Class: Aws::Athena::Types::ImportNotebookInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::ImportNotebookInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique case-sensitive string used to ensure the request to import the notebook is idempotent (executes only once).
-
#name ⇒ String
The name of the notebook to import.
-
#notebook_s3_location_uri ⇒ String
A URI that specifies the Amazon S3 location of a notebook file in ‘ipynb` format.
-
#payload ⇒ String
The notebook content to be imported.
-
#type ⇒ String
The notebook content type.
-
#work_group ⇒ String
The name of the Spark enabled workgroup to import the notebook to.
Instance Attribute Details
#client_request_token ⇒ String
A unique case-sensitive string used to ensure the request to import the notebook is idempotent (executes only once).
This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for you. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.
2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 |
# File 'lib/aws-sdk-athena/types.rb', line 2304 class ImportNotebookInput < Struct.new( :work_group, :name, :payload, :type, :notebook_s3_location_uri, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the notebook to import.
2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 |
# File 'lib/aws-sdk-athena/types.rb', line 2304 class ImportNotebookInput < Struct.new( :work_group, :name, :payload, :type, :notebook_s3_location_uri, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#notebook_s3_location_uri ⇒ String
A URI that specifies the Amazon S3 location of a notebook file in ‘ipynb` format.
2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 |
# File 'lib/aws-sdk-athena/types.rb', line 2304 class ImportNotebookInput < Struct.new( :work_group, :name, :payload, :type, :notebook_s3_location_uri, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ String
The notebook content to be imported. The payload must be in ‘ipynb` format.
2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 |
# File 'lib/aws-sdk-athena/types.rb', line 2304 class ImportNotebookInput < Struct.new( :work_group, :name, :payload, :type, :notebook_s3_location_uri, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The notebook content type. Currently, the only valid type is ‘IPYNB`.
2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 |
# File 'lib/aws-sdk-athena/types.rb', line 2304 class ImportNotebookInput < Struct.new( :work_group, :name, :payload, :type, :notebook_s3_location_uri, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#work_group ⇒ String
The name of the Spark enabled workgroup to import the notebook to.
2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 |
# File 'lib/aws-sdk-athena/types.rb', line 2304 class ImportNotebookInput < Struct.new( :work_group, :name, :payload, :type, :notebook_s3_location_uri, :client_request_token) SENSITIVE = [] include Aws::Structure end |