Class: Aws::Athena::Types::ListCalculationExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::ListCalculationExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of calculation executions to return.
-
#next_token ⇒ String
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
-
#session_id ⇒ String
The session ID.
-
#state_filter ⇒ String
A filter for a specific calculation execution state.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of calculation executions to return.
2448 2449 2450 2451 2452 2453 2454 2455 |
# File 'lib/aws-sdk-athena/types.rb', line 2448 class ListCalculationExecutionsRequest < Struct.new( :session_id, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
2448 2449 2450 2451 2452 2453 2454 2455 |
# File 'lib/aws-sdk-athena/types.rb', line 2448 class ListCalculationExecutionsRequest < Struct.new( :session_id, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The session ID.
2448 2449 2450 2451 2452 2453 2454 2455 |
# File 'lib/aws-sdk-athena/types.rb', line 2448 class ListCalculationExecutionsRequest < Struct.new( :session_id, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#state_filter ⇒ String
A filter for a specific calculation execution state. A description of each state follows.
CREATING - The calculation is in the process of being created.
CREATED - The calculation has been created and is ready to run.
QUEUED - The calculation has been queued for processing.
RUNNING - The calculation is running.
CANCELING - A request to cancel the calculation has been received and the system is working to stop it.
CANCELED - The calculation is no longer running as the result of a cancel request.
COMPLETED - The calculation has completed without error.
FAILED - The calculation failed and is no longer running.
2448 2449 2450 2451 2452 2453 2454 2455 |
# File 'lib/aws-sdk-athena/types.rb', line 2448 class ListCalculationExecutionsRequest < Struct.new( :session_id, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |