Class: Aws::Athena::Types::ListCalculationExecutionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-athena/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#calculationsArray<Types::CalculationSummary>

A list of CalculationSummary objects.



2470
2471
2472
2473
2474
2475
# File 'lib/aws-sdk-athena/types.rb', line 2470

class ListCalculationExecutionsResponse < Struct.new(
  :next_token,
  :calculations)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.



2470
2471
2472
2473
2474
2475
# File 'lib/aws-sdk-athena/types.rb', line 2470

class ListCalculationExecutionsResponse < Struct.new(
  :next_token,
  :calculations)
  SENSITIVE = []
  include Aws::Structure
end