Class: Aws::Athena::Types::ListNotebookSessionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::ListNotebookSessionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of notebook sessions to return.
-
#next_token ⇒ String
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
-
#notebook_id ⇒ String
The ID of the notebook to list sessions for.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of notebook sessions to return.
2835 2836 2837 2838 2839 2840 2841 |
# File 'lib/aws-sdk-athena/types.rb', line 2835 class ListNotebookSessionsRequest < Struct.new( :notebook_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
2835 2836 2837 2838 2839 2840 2841 |
# File 'lib/aws-sdk-athena/types.rb', line 2835 class ListNotebookSessionsRequest < Struct.new( :notebook_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#notebook_id ⇒ String
The ID of the notebook to list sessions for.
2835 2836 2837 2838 2839 2840 2841 |
# File 'lib/aws-sdk-athena/types.rb', line 2835 class ListNotebookSessionsRequest < Struct.new( :notebook_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |