Class: Aws::Athena::Types::ListPreparedStatementsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-athena/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in this request.



2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-athena/types.rb', line 2880

class ListPreparedStatementsInput < Struct.new(
  :work_group,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.



2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-athena/types.rb', line 2880

class ListPreparedStatementsInput < Struct.new(
  :work_group,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#work_groupString

The workgroup to list the prepared statements for.



2880
2881
2882
2883
2884
2885
2886
# File 'lib/aws-sdk-athena/types.rb', line 2880

class ListPreparedStatementsInput < Struct.new(
  :work_group,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end