Class: Aws::Athena::Types::ListSessionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::ListSessionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of sessions to return.
-
#next_token ⇒ String
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
-
#state_filter ⇒ String
A filter for a specific session state.
-
#work_group ⇒ String
The workgroup to which the session belongs.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of sessions to return.
2993 2994 2995 2996 2997 2998 2999 3000 |
# File 'lib/aws-sdk-athena/types.rb', line 2993 class ListSessionsRequest < Struct.new( :work_group, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
2993 2994 2995 2996 2997 2998 2999 3000 |
# File 'lib/aws-sdk-athena/types.rb', line 2993 class ListSessionsRequest < Struct.new( :work_group, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#state_filter ⇒ String
A filter for a specific session state. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
2993 2994 2995 2996 2997 2998 2999 3000 |
# File 'lib/aws-sdk-athena/types.rb', line 2993 class ListSessionsRequest < Struct.new( :work_group, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#work_group ⇒ String
The workgroup to which the session belongs.
2993 2994 2995 2996 2997 2998 2999 3000 |
# File 'lib/aws-sdk-athena/types.rb', line 2993 class ListSessionsRequest < Struct.new( :work_group, :state_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |