Class: Aws::Athena::Types::ListTableMetadataInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-athena/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_nameString

The name of the data catalog for which table metadata should be returned.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
# File 'lib/aws-sdk-athena/types.rb', line 3056

class ListTableMetadataInput < Struct.new(
  :catalog_name,
  :database_name,
  :expression,
  :next_token,
  :max_results,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database for which table metadata should be returned.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
# File 'lib/aws-sdk-athena/types.rb', line 3056

class ListTableMetadataInput < Struct.new(
  :catalog_name,
  :database_name,
  :expression,
  :next_token,
  :max_results,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end

#expressionString

A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
# File 'lib/aws-sdk-athena/types.rb', line 3056

class ListTableMetadataInput < Struct.new(
  :catalog_name,
  :database_name,
  :expression,
  :next_token,
  :max_results,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Specifies the maximum number of results to return.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
# File 'lib/aws-sdk-athena/types.rb', line 3056

class ListTableMetadataInput < Struct.new(
  :catalog_name,
  :database_name,
  :expression,
  :next_token,
  :max_results,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
# File 'lib/aws-sdk-athena/types.rb', line 3056

class ListTableMetadataInput < Struct.new(
  :catalog_name,
  :database_name,
  :expression,
  :next_token,
  :max_results,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end

#work_groupString

The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.



3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
# File 'lib/aws-sdk-athena/types.rb', line 3056

class ListTableMetadataInput < Struct.new(
  :catalog_name,
  :database_name,
  :expression,
  :next_token,
  :max_results,
  :work_group)
  SENSITIVE = []
  include Aws::Structure
end