Class: Aws::Athena::Types::MetadataException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::MetadataException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
An exception that Athena received when it called a custom metastore. Occurs if the error is not caused by user input (InvalidRequestException) or from the Athena platform (InternalServerException). For example, if a user-created Lambda function is missing permissions, the Lambda 4XX exception is returned in a MetadataException.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
3276 3277 3278 3279 3280 |
# File 'lib/aws-sdk-athena/types.rb', line 3276 class MetadataException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |