Class: Aws::Athena::Types::QueryRuntimeStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-athena/types.rb

Overview

The query execution timeline, statistics on input and output rows and bytes, and the different query stages that form the query execution plan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#output_stageTypes::QueryStage

Stage statistics such as input and output rows and bytes, execution time, and stage state. This information also includes substages and the query stage plan.

Returns:



3783
3784
3785
3786
3787
3788
3789
# File 'lib/aws-sdk-athena/types.rb', line 3783

class QueryRuntimeStatistics < Struct.new(
  :timeline,
  :rows,
  :output_stage)
  SENSITIVE = []
  include Aws::Structure
end

#rowsTypes::QueryRuntimeStatisticsRows

Statistics such as input rows and bytes read by the query, rows and bytes output by the query, and the number of rows written by the query.

Returns:



3783
3784
3785
3786
3787
3788
3789
# File 'lib/aws-sdk-athena/types.rb', line 3783

class QueryRuntimeStatistics < Struct.new(
  :timeline,
  :rows,
  :output_stage)
  SENSITIVE = []
  include Aws::Structure
end

#timelineTypes::QueryRuntimeStatisticsTimeline

Timeline statistics such as query queue time, planning time, execution time, service processing time, and total execution time.

Returns:



3783
3784
3785
3786
3787
3788
3789
# File 'lib/aws-sdk-athena/types.rb', line 3783

class QueryRuntimeStatistics < Struct.new(
  :timeline,
  :rows,
  :output_stage)
  SENSITIVE = []
  include Aws::Structure
end