Class: Aws::Athena::Types::WorkGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::WorkGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
A workgroup, which contains a name, description, creation time, state, and other configuration, listed under WorkGroup$Configuration. Each workgroup enables you to isolate queries for you or your group of users from other queries in the same account, to configure the query results location and the encryption configuration (known as workgroup settings), to enable sending query metrics to Amazon CloudWatch, and to establish per-query data usage control limits for all queries in a workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::WorkGroupConfiguration
The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup.
-
#creation_time ⇒ Time
The date and time the workgroup was created.
-
#description ⇒ String
The workgroup description.
-
#identity_center_application_arn ⇒ String
The ARN of the IAM Identity Center enabled application associated with the workgroup.
-
#name ⇒ String
The workgroup name.
-
#state ⇒ String
The state of the workgroup: ENABLED or DISABLED.
Instance Attribute Details
#configuration ⇒ Types::WorkGroupConfiguration
The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption configuration, if any, used for query and calculation results; whether the Amazon CloudWatch Metrics are enabled for the workgroup; whether workgroup settings override client-side settings; and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 |
# File 'lib/aws-sdk-athena/types.rb', line 5394 class WorkGroup < Struct.new( :name, :state, :configuration, :description, :creation_time, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time the workgroup was created.
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 |
# File 'lib/aws-sdk-athena/types.rb', line 5394 class WorkGroup < Struct.new( :name, :state, :configuration, :description, :creation_time, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The workgroup description.
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 |
# File 'lib/aws-sdk-athena/types.rb', line 5394 class WorkGroup < Struct.new( :name, :state, :configuration, :description, :creation_time, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#identity_center_application_arn ⇒ String
The ARN of the IAM Identity Center enabled application associated with the workgroup.
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 |
# File 'lib/aws-sdk-athena/types.rb', line 5394 class WorkGroup < Struct.new( :name, :state, :configuration, :description, :creation_time, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The workgroup name.
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 |
# File 'lib/aws-sdk-athena/types.rb', line 5394 class WorkGroup < Struct.new( :name, :state, :configuration, :description, :creation_time, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the workgroup: ENABLED or DISABLED.
5394 5395 5396 5397 5398 5399 5400 5401 5402 5403 |
# File 'lib/aws-sdk-athena/types.rb', line 5394 class WorkGroup < Struct.new( :name, :state, :configuration, :description, :creation_time, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |