Class: Aws::Athena::Types::WorkGroupConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::WorkGroupConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
The configuration of the workgroup, which includes the location in Amazon S3 where query and calculation results are stored, the encryption option, if any, used for query and calculation results, whether the Amazon CloudWatch Metrics are enabled for the workgroup and whether workgroup settings override query settings, and the data usage limits for the amount of data scanned per query or per workgroup. The workgroup settings override is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See WorkGroupConfiguration$EnforceWorkGroupConfiguration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_configuration ⇒ String
Specifies a user defined JSON string that is passed to the notebook engine.
-
#bytes_scanned_cutoff_per_query ⇒ Integer
The upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.
-
#customer_content_encryption_configuration ⇒ Types::CustomerContentEncryptionConfiguration
Specifies the KMS key that is used to encrypt the user’s data stores in Athena.
-
#enable_minimum_encryption_configuration ⇒ Boolean
Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3.
-
#enforce_work_group_configuration ⇒ Boolean
If set to “true”, the settings for the workgroup override client-side settings.
-
#engine_configuration ⇒ Types::EngineConfiguration
The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity.
-
#engine_version ⇒ Types::EngineVersion
The engine version that all queries running on the workgroup use.
-
#execution_role ⇒ String
The ARN of the execution role used to access user resources for Spark sessions and IAM Identity Center enabled workgroups.
-
#identity_center_configuration ⇒ Types::IdentityCenterConfiguration
Specifies whether the workgroup is IAM Identity Center supported.
-
#managed_query_results_configuration ⇒ Types::ManagedQueryResultsConfiguration
The configuration for storing results in Athena owned storage, which includes whether this feature is enabled; whether encryption configuration, if any, is used for encrypting query results.
-
#monitoring_configuration ⇒ Types::MonitoringConfiguration
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
-
#publish_cloud_watch_metrics_enabled ⇒ Boolean
Indicates that the Amazon CloudWatch metrics are enabled for the workgroup.
-
#query_results_s3_access_grants_configuration ⇒ Types::QueryResultsS3AccessGrantsConfiguration
Specifies whether Amazon S3 access grants are enabled for query results.
-
#requester_pays_enabled ⇒ Boolean
If set to
true, allows members assigned to a workgroup to reference Amazon S3 Requester Pays buckets in queries. -
#result_configuration ⇒ Types::ResultConfiguration
The configuration for the workgroup, which includes the location in Amazon S3 where query and calculation results are stored and the encryption option, if any, used for query and calculation results.
Instance Attribute Details
#additional_configuration ⇒ String
Specifies a user defined JSON string that is passed to the notebook engine.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#bytes_scanned_cutoff_per_query ⇒ Integer
The upper data usage limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#customer_content_encryption_configuration ⇒ Types::CustomerContentEncryptionConfiguration
Specifies the KMS key that is used to encrypt the user’s data stores in Athena. This setting does not apply to Athena SQL workgroups.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#enable_minimum_encryption_configuration ⇒ Boolean
Enforces a minimal level of encryption for the workgroup for query and calculation results that are written to Amazon S3. When enabled, workgroup users can set encryption only to the minimum level set by the administrator or higher when they submit queries.
The EnforceWorkGroupConfiguration setting takes precedence over the EnableMinimumEncryptionConfiguration flag. This means that if EnforceWorkGroupConfiguration is true, the EnableMinimumEncryptionConfiguration flag is ignored, and the workgroup configuration for encryption is used.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#enforce_work_group_configuration ⇒ Boolean
If set to “true”, the settings for the workgroup override client-side settings. If set to “false”, client-side settings are used. This property is not required for Apache Spark enabled workgroups. For more information, see [Workgroup Settings Override Client-Side Settings].
[1]: docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#engine_configuration ⇒ Types::EngineConfiguration
The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).
To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ Types::EngineVersion
The engine version that all queries running on the workgroup use. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The ARN of the execution role used to access user resources for Spark sessions and IAM Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and IAM Identity Center enabled workgroups. The property is required for IAM Identity Center enabled workgroups.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#identity_center_configuration ⇒ Types::IdentityCenterConfiguration
Specifies whether the workgroup is IAM Identity Center supported.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#managed_query_results_configuration ⇒ Types::ManagedQueryResultsConfiguration
The configuration for storing results in Athena owned storage, which includes whether this feature is enabled; whether encryption configuration, if any, is used for encrypting query results.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#monitoring_configuration ⇒ Types::MonitoringConfiguration
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#publish_cloud_watch_metrics_enabled ⇒ Boolean
Indicates that the Amazon CloudWatch metrics are enabled for the workgroup.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#query_results_s3_access_grants_configuration ⇒ Types::QueryResultsS3AccessGrantsConfiguration
Specifies whether Amazon S3 access grants are enabled for query results.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#requester_pays_enabled ⇒ Boolean
If set to true, allows members assigned to a workgroup to reference Amazon S3 Requester Pays buckets in queries. If set to false, workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is false. For more information about Requester Pays buckets, see [Requester Pays Buckets] in the *Amazon Simple Storage Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/RequesterPaysBuckets.html
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |
#result_configuration ⇒ Types::ResultConfiguration
The configuration for the workgroup, which includes the location in Amazon S3 where query and calculation results are stored and the encryption option, if any, used for query and calculation results. To run the query, you must specify the query results location using one of the ways: either in the workgroup using this setting, or for individual queries (client-side), using ResultConfiguration$OutputLocation. If none of them is set, Athena issues an error that no output location is provided.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 |
# File 'lib/aws-sdk-athena/types.rb', line 5537 class WorkGroupConfiguration < Struct.new( :result_configuration, :managed_query_results_configuration, :enforce_work_group_configuration, :publish_cloud_watch_metrics_enabled, :bytes_scanned_cutoff_per_query, :requester_pays_enabled, :engine_version, :additional_configuration, :execution_role, :monitoring_configuration, :engine_configuration, :customer_content_encryption_configuration, :enable_minimum_encryption_configuration, :identity_center_configuration, :query_results_s3_access_grants_configuration) SENSITIVE = [] include Aws::Structure end |