Class: Aws::Athena::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Athena::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-athena/client.rb
Overview
An API client for Athena. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Athena::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_named_query(params = {}) ⇒ Types::BatchGetNamedQueryOutput
Returns the details of a single named query or a list of up to 50 queries, which you provide as an array of query ID strings.
-
#batch_get_prepared_statement(params = {}) ⇒ Types::BatchGetPreparedStatementOutput
Returns the details of a single prepared statement or a list of up to 256 prepared statements for the array of prepared statement names that you provide.
-
#batch_get_query_execution(params = {}) ⇒ Types::BatchGetQueryExecutionOutput
Returns the details of a single query execution or a list of up to 50 query executions, which you provide as an array of query execution ID strings.
-
#cancel_capacity_reservation(params = {}) ⇒ Struct
Cancels the capacity reservation with the specified name.
-
#create_capacity_reservation(params = {}) ⇒ Struct
Creates a capacity reservation with the specified name and number of requested data processing units.
-
#create_data_catalog(params = {}) ⇒ Types::CreateDataCatalogOutput
Creates (registers) a data catalog with the specified name and properties.
-
#create_named_query(params = {}) ⇒ Types::CreateNamedQueryOutput
Creates a named query in the specified workgroup.
-
#create_notebook(params = {}) ⇒ Types::CreateNotebookOutput
Creates an empty ‘ipynb` file in the specified Apache Spark enabled workgroup.
-
#create_prepared_statement(params = {}) ⇒ Struct
Creates a prepared statement for use with SQL queries in Athena.
-
#create_presigned_notebook_url(params = {}) ⇒ Types::CreatePresignedNotebookUrlResponse
Gets an authentication token and the URL at which the notebook can be accessed.
-
#create_work_group(params = {}) ⇒ Struct
Creates a workgroup with the specified name.
-
#delete_capacity_reservation(params = {}) ⇒ Struct
Deletes a cancelled capacity reservation.
-
#delete_data_catalog(params = {}) ⇒ Types::DeleteDataCatalogOutput
Deletes a data catalog.
-
#delete_named_query(params = {}) ⇒ Struct
Deletes the named query if you have access to the workgroup in which the query was saved.
-
#delete_notebook(params = {}) ⇒ Struct
Deletes the specified notebook.
-
#delete_prepared_statement(params = {}) ⇒ Struct
Deletes the prepared statement with the specified name from the specified workgroup.
-
#delete_work_group(params = {}) ⇒ Struct
Deletes the workgroup with the specified name.
-
#export_notebook(params = {}) ⇒ Types::ExportNotebookOutput
Exports the specified notebook and its metadata.
-
#get_calculation_execution(params = {}) ⇒ Types::GetCalculationExecutionResponse
Describes a previously submitted calculation execution.
-
#get_calculation_execution_code(params = {}) ⇒ Types::GetCalculationExecutionCodeResponse
Retrieves the unencrypted code that was executed for the calculation.
-
#get_calculation_execution_status(params = {}) ⇒ Types::GetCalculationExecutionStatusResponse
Gets the status of a current calculation.
-
#get_capacity_assignment_configuration(params = {}) ⇒ Types::GetCapacityAssignmentConfigurationOutput
Gets the capacity assignment configuration for a capacity reservation, if one exists.
-
#get_capacity_reservation(params = {}) ⇒ Types::GetCapacityReservationOutput
Returns information about the capacity reservation with the specified name.
-
#get_data_catalog(params = {}) ⇒ Types::GetDataCatalogOutput
Returns the specified data catalog.
-
#get_database(params = {}) ⇒ Types::GetDatabaseOutput
Returns a database object for the specified database and data catalog.
-
#get_named_query(params = {}) ⇒ Types::GetNamedQueryOutput
Returns information about a single query.
-
#get_notebook_metadata(params = {}) ⇒ Types::GetNotebookMetadataOutput
Retrieves notebook metadata for the specified notebook ID.
-
#get_prepared_statement(params = {}) ⇒ Types::GetPreparedStatementOutput
Retrieves the prepared statement with the specified name from the specified workgroup.
-
#get_query_execution(params = {}) ⇒ Types::GetQueryExecutionOutput
Returns information about a single execution of a query if you have access to the workgroup in which the query ran.
-
#get_query_results(params = {}) ⇒ Types::GetQueryResultsOutput
Streams the results of a single query execution specified by ‘QueryExecutionId` from the Athena query results location in Amazon S3.
-
#get_query_runtime_statistics(params = {}) ⇒ Types::GetQueryRuntimeStatisticsOutput
Returns query execution runtime statistics related to a single execution of a query if you have access to the workgroup in which the query ran.
-
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Gets the Live UI/Persistence UI for a session.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets the full details of a previously created session, including the session status and configuration.
-
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Gets a connection endpoint and authentication token for a given session Id.
-
#get_session_status(params = {}) ⇒ Types::GetSessionStatusResponse
Gets the current status of a session.
-
#get_table_metadata(params = {}) ⇒ Types::GetTableMetadataOutput
Returns table metadata for the specified catalog, database, and table.
-
#get_work_group(params = {}) ⇒ Types::GetWorkGroupOutput
Returns information about the workgroup with the specified name.
-
#import_notebook(params = {}) ⇒ Types::ImportNotebookOutput
Imports a single ‘ipynb` file to a Spark enabled workgroup.
-
#list_application_dpu_sizes(params = {}) ⇒ Types::ListApplicationDPUSizesOutput
Returns the supported DPU sizes for the supported application runtimes (for example, ‘Athena notebook version 1`).
-
#list_calculation_executions(params = {}) ⇒ Types::ListCalculationExecutionsResponse
Lists the calculations that have been submitted to a session in descending order.
-
#list_capacity_reservations(params = {}) ⇒ Types::ListCapacityReservationsOutput
Lists the capacity reservations for the current account.
-
#list_data_catalogs(params = {}) ⇒ Types::ListDataCatalogsOutput
Lists the data catalogs in the current Amazon Web Services account.
-
#list_databases(params = {}) ⇒ Types::ListDatabasesOutput
Lists the databases in the specified data catalog.
-
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsOutput
Returns a list of engine versions that are available to choose from, including the Auto option.
-
#list_executors(params = {}) ⇒ Types::ListExecutorsResponse
Lists, in descending order, the executors that joined a session.
-
#list_named_queries(params = {}) ⇒ Types::ListNamedQueriesOutput
Provides a list of available query IDs only for queries saved in the specified workgroup.
-
#list_notebook_metadata(params = {}) ⇒ Types::ListNotebookMetadataOutput
Displays the notebook files for the specified workgroup in paginated format.
-
#list_notebook_sessions(params = {}) ⇒ Types::ListNotebookSessionsResponse
Lists, in descending order, the sessions that have been created in a notebook that are in an active state like ‘CREATING`, `CREATED`, `IDLE` or `BUSY`.
-
#list_prepared_statements(params = {}) ⇒ Types::ListPreparedStatementsOutput
Lists the prepared statements in the specified workgroup.
-
#list_query_executions(params = {}) ⇒ Types::ListQueryExecutionsOutput
Provides a list of available query execution IDs for the queries in the specified workgroup.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists the sessions in a workgroup that are in an active state like ‘CREATING`, `CREATED`, `IDLE`, or `BUSY`.
-
#list_table_metadata(params = {}) ⇒ Types::ListTableMetadataOutput
Lists the metadata for the tables in the specified data catalog database.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with an Athena resource.
-
#list_work_groups(params = {}) ⇒ Types::ListWorkGroupsOutput
Lists available workgroups for the account.
-
#put_capacity_assignment_configuration(params = {}) ⇒ Struct
Puts a new capacity assignment configuration for a specified capacity reservation.
-
#start_calculation_execution(params = {}) ⇒ Types::StartCalculationExecutionResponse
Submits calculations for execution within a session.
-
#start_query_execution(params = {}) ⇒ Types::StartQueryExecutionOutput
Runs the SQL query statements contained in the ‘Query`.
-
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates a session for running calculations within a workgroup.
-
#stop_calculation_execution(params = {}) ⇒ Types::StopCalculationExecutionResponse
Requests the cancellation of a calculation.
-
#stop_query_execution(params = {}) ⇒ Struct
Stops a query execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to an Athena resource.
-
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates an active session.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an Athena resource.
-
#update_capacity_reservation(params = {}) ⇒ Struct
Updates the number of requested data processing units for the capacity reservation with the specified name.
-
#update_data_catalog(params = {}) ⇒ Struct
Updates the data catalog that has the specified name.
-
#update_named_query(params = {}) ⇒ Struct
Updates a NamedQuery object.
-
#update_notebook(params = {}) ⇒ Struct
Updates the contents of a Spark notebook.
-
#update_notebook_metadata(params = {}) ⇒ Struct
Updates the metadata for a notebook.
-
#update_prepared_statement(params = {}) ⇒ Struct
Updates a prepared statement.
-
#update_work_group(params = {}) ⇒ Struct
Updates the workgroup with the specified name.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-athena/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4147 4148 4149 |
# File 'lib/aws-sdk-athena/client.rb', line 4147 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4150 4151 4152 |
# File 'lib/aws-sdk-athena/client.rb', line 4150 def errors_module Errors end |
Instance Method Details
#batch_get_named_query(params = {}) ⇒ Types::BatchGetNamedQueryOutput
Returns the details of a single named query or a list of up to 50 queries, which you provide as an array of query ID strings. Requires you to have access to the workgroup in which the queries were saved. Use ListNamedQueriesInput to get the list of named query IDs in the specified workgroup. If information could not be retrieved for a submitted query ID, information about the query ID submitted is listed under UnprocessedNamedQueryId. Named queries differ from executed queries. Use BatchGetQueryExecutionInput to get details about each unique query execution, and ListQueryExecutionsInput to get a list of query execution IDs.
529 530 531 532 |
# File 'lib/aws-sdk-athena/client.rb', line 529 def batch_get_named_query(params = {}, = {}) req = build_request(:batch_get_named_query, params) req.send_request() end |
#batch_get_prepared_statement(params = {}) ⇒ Types::BatchGetPreparedStatementOutput
Returns the details of a single prepared statement or a list of up to 256 prepared statements for the array of prepared statement names that you provide. Requires you to have access to the workgroup to which the prepared statements belong. If a prepared statement cannot be retrieved for the name specified, the statement is listed in ‘UnprocessedPreparedStatementNames`.
576 577 578 579 |
# File 'lib/aws-sdk-athena/client.rb', line 576 def batch_get_prepared_statement(params = {}, = {}) req = build_request(:batch_get_prepared_statement, params) req.send_request() end |
#batch_get_query_execution(params = {}) ⇒ Types::BatchGetQueryExecutionOutput
Returns the details of a single query execution or a list of up to 50 query executions, which you provide as an array of query execution ID strings. Requires you to have access to the workgroup in which the queries ran. To get a list of query execution IDs, use ListQueryExecutionsInput$WorkGroup. Query executions differ from named (saved) queries. Use BatchGetNamedQueryInput to get details about named queries.
656 657 658 659 |
# File 'lib/aws-sdk-athena/client.rb', line 656 def batch_get_query_execution(params = {}, = {}) req = build_request(:batch_get_query_execution, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 |
# File 'lib/aws-sdk-athena/client.rb', line 4120 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Athena') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-athena' context[:gem_version] = '1.117.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_capacity_reservation(params = {}) ⇒ Struct
Cancels the capacity reservation with the specified name. Cancelled reservations remain in your account and will be deleted 45 days after cancellation. During the 45 days, you cannot re-purpose or reuse a reservation that has been cancelled, but you can refer to its tags and view it for historical reference.
682 683 684 685 |
# File 'lib/aws-sdk-athena/client.rb', line 682 def cancel_capacity_reservation(params = {}, = {}) req = build_request(:cancel_capacity_reservation, params) req.send_request() end |
#create_capacity_reservation(params = {}) ⇒ Struct
Creates a capacity reservation with the specified name and number of requested data processing units.
718 719 720 721 |
# File 'lib/aws-sdk-athena/client.rb', line 718 def create_capacity_reservation(params = {}, = {}) req = build_request(:create_capacity_reservation, params) req.send_request() end |
#create_data_catalog(params = {}) ⇒ Types::CreateDataCatalogOutput
Creates (registers) a data catalog with the specified name and properties. Catalogs created are visible to all users of the same Amazon Web Services account.
For a ‘FEDERATED` catalog, this API operation creates the following resources.
-
CFN Stack Name with a maximum length of 128 characters and prefix ‘athenafederatedcatalog-CATALOG_NAME_SANITIZED` with length 23 characters.
-
Lambda Function Name with a maximum length of 64 characters and prefix ‘athenafederatedcatalog_CATALOG_NAME_SANITIZED` with length 23 characters.
-
Glue Connection Name with a maximum length of 255 characters and a prefix ‘athenafederatedcatalog_CATALOG_NAME_SANITIZED` with length 23 characters.
873 874 875 876 |
# File 'lib/aws-sdk-athena/client.rb', line 873 def create_data_catalog(params = {}, = {}) req = build_request(:create_data_catalog, params) req.send_request() end |
#create_named_query(params = {}) ⇒ Types::CreateNamedQueryOutput
Creates a named query in the specified workgroup. Requires that you have access to the workgroup.
935 936 937 938 |
# File 'lib/aws-sdk-athena/client.rb', line 935 def create_named_query(params = {}, = {}) req = build_request(:create_named_query, params) req.send_request() end |
#create_notebook(params = {}) ⇒ Types::CreateNotebookOutput
Creates an empty ‘ipynb` file in the specified Apache Spark enabled workgroup. Throws an error if a file in the workgroup with the same name already exists.
982 983 984 985 |
# File 'lib/aws-sdk-athena/client.rb', line 982 def create_notebook(params = {}, = {}) req = build_request(:create_notebook, params) req.send_request() end |
#create_prepared_statement(params = {}) ⇒ Struct
Creates a prepared statement for use with SQL queries in Athena.
1016 1017 1018 1019 |
# File 'lib/aws-sdk-athena/client.rb', line 1016 def create_prepared_statement(params = {}, = {}) req = build_request(:create_prepared_statement, params) req.send_request() end |
#create_presigned_notebook_url(params = {}) ⇒ Types::CreatePresignedNotebookUrlResponse
Gets an authentication token and the URL at which the notebook can be accessed. During programmatic access, ‘CreatePresignedNotebookUrl` must be called every 10 minutes to refresh the authentication token. For information about granting programmatic access, see [Grant programmatic access].
[1]: docs.aws.amazon.com/athena/latest/ug/setting-up.html#setting-up-grant-programmatic-access
1056 1057 1058 1059 |
# File 'lib/aws-sdk-athena/client.rb', line 1056 def create_presigned_notebook_url(params = {}, = {}) req = build_request(:create_presigned_notebook_url, params) req.send_request() end |
#create_work_group(params = {}) ⇒ Struct
Creates a workgroup with the specified name. A workgroup can be an Apache Spark enabled workgroup or an Athena SQL workgroup.
1185 1186 1187 1188 |
# File 'lib/aws-sdk-athena/client.rb', line 1185 def create_work_group(params = {}, = {}) req = build_request(:create_work_group, params) req.send_request() end |
#delete_capacity_reservation(params = {}) ⇒ Struct
Deletes a cancelled capacity reservation. A reservation must be cancelled before it can be deleted. A deleted reservation is immediately removed from your account and can no longer be referenced, including by its ARN. A deleted reservation cannot be called by ‘GetCapacityReservation`, and deleted reservations do not appear in the output of `ListCapacityReservations`.
1212 1213 1214 1215 |
# File 'lib/aws-sdk-athena/client.rb', line 1212 def delete_capacity_reservation(params = {}, = {}) req = build_request(:delete_capacity_reservation, params) req.send_request() end |
#delete_data_catalog(params = {}) ⇒ Types::DeleteDataCatalogOutput
Deletes a data catalog.
1254 1255 1256 1257 |
# File 'lib/aws-sdk-athena/client.rb', line 1254 def delete_data_catalog(params = {}, = {}) req = build_request(:delete_data_catalog, params) req.send_request() end |
#delete_named_query(params = {}) ⇒ Struct
Deletes the named query if you have access to the workgroup in which the query was saved.
1280 1281 1282 1283 |
# File 'lib/aws-sdk-athena/client.rb', line 1280 def delete_named_query(params = {}, = {}) req = build_request(:delete_named_query, params) req.send_request() end |
#delete_notebook(params = {}) ⇒ Struct
Deletes the specified notebook.
1302 1303 1304 1305 |
# File 'lib/aws-sdk-athena/client.rb', line 1302 def delete_notebook(params = {}, = {}) req = build_request(:delete_notebook, params) req.send_request() end |
#delete_prepared_statement(params = {}) ⇒ Struct
Deletes the prepared statement with the specified name from the specified workgroup.
1329 1330 1331 1332 |
# File 'lib/aws-sdk-athena/client.rb', line 1329 def delete_prepared_statement(params = {}, = {}) req = build_request(:delete_prepared_statement, params) req.send_request() end |
#delete_work_group(params = {}) ⇒ Struct
Deletes the workgroup with the specified name. The primary workgroup cannot be deleted.
1357 1358 1359 1360 |
# File 'lib/aws-sdk-athena/client.rb', line 1357 def delete_work_group(params = {}, = {}) req = build_request(:delete_work_group, params) req.send_request() end |
#export_notebook(params = {}) ⇒ Types::ExportNotebookOutput
Exports the specified notebook and its metadata.
1392 1393 1394 1395 |
# File 'lib/aws-sdk-athena/client.rb', line 1392 def export_notebook(params = {}, = {}) req = build_request(:export_notebook, params) req.send_request() end |
#get_calculation_execution(params = {}) ⇒ Types::GetCalculationExecutionResponse
Describes a previously submitted calculation execution.
1439 1440 1441 1442 |
# File 'lib/aws-sdk-athena/client.rb', line 1439 def get_calculation_execution(params = {}, = {}) req = build_request(:get_calculation_execution, params) req.send_request() end |
#get_calculation_execution_code(params = {}) ⇒ Types::GetCalculationExecutionCodeResponse
Retrieves the unencrypted code that was executed for the calculation.
1467 1468 1469 1470 |
# File 'lib/aws-sdk-athena/client.rb', line 1467 def get_calculation_execution_code(params = {}, = {}) req = build_request(:get_calculation_execution_code, params) req.send_request() end |
#get_calculation_execution_status(params = {}) ⇒ Types::GetCalculationExecutionStatusResponse
Gets the status of a current calculation.
1501 1502 1503 1504 |
# File 'lib/aws-sdk-athena/client.rb', line 1501 def get_calculation_execution_status(params = {}, = {}) req = build_request(:get_calculation_execution_status, params) req.send_request() end |
#get_capacity_assignment_configuration(params = {}) ⇒ Types::GetCapacityAssignmentConfigurationOutput
Gets the capacity assignment configuration for a capacity reservation, if one exists.
1534 1535 1536 1537 |
# File 'lib/aws-sdk-athena/client.rb', line 1534 def get_capacity_assignment_configuration(params = {}, = {}) req = build_request(:get_capacity_assignment_configuration, params) req.send_request() end |
#get_capacity_reservation(params = {}) ⇒ Types::GetCapacityReservationOutput
Returns information about the capacity reservation with the specified name.
1572 1573 1574 1575 |
# File 'lib/aws-sdk-athena/client.rb', line 1572 def get_capacity_reservation(params = {}, = {}) req = build_request(:get_capacity_reservation, params) req.send_request() end |
#get_data_catalog(params = {}) ⇒ Types::GetDataCatalogOutput
Returns the specified data catalog.
1612 1613 1614 1615 |
# File 'lib/aws-sdk-athena/client.rb', line 1612 def get_data_catalog(params = {}, = {}) req = build_request(:get_data_catalog, params) req.send_request() end |
#get_database(params = {}) ⇒ Types::GetDatabaseOutput
Returns a database object for the specified database and data catalog.
1653 1654 1655 1656 |
# File 'lib/aws-sdk-athena/client.rb', line 1653 def get_database(params = {}, = {}) req = build_request(:get_database, params) req.send_request() end |
#get_named_query(params = {}) ⇒ Types::GetNamedQueryOutput
Returns information about a single query. Requires that you have access to the workgroup in which the query was saved.
1687 1688 1689 1690 |
# File 'lib/aws-sdk-athena/client.rb', line 1687 def get_named_query(params = {}, = {}) req = build_request(:get_named_query, params) req.send_request() end |
#get_notebook_metadata(params = {}) ⇒ Types::GetNotebookMetadataOutput
Retrieves notebook metadata for the specified notebook ID.
1720 1721 1722 1723 |
# File 'lib/aws-sdk-athena/client.rb', line 1720 def (params = {}, = {}) req = build_request(:get_notebook_metadata, params) req.send_request() end |
#get_prepared_statement(params = {}) ⇒ Types::GetPreparedStatementOutput
Retrieves the prepared statement with the specified name from the specified workgroup.
1757 1758 1759 1760 |
# File 'lib/aws-sdk-athena/client.rb', line 1757 def get_prepared_statement(params = {}, = {}) req = build_request(:get_prepared_statement, params) req.send_request() end |
#get_query_execution(params = {}) ⇒ Types::GetQueryExecutionOutput
Returns information about a single execution of a query if you have access to the workgroup in which the query ran. Each time a query executes, information about the query execution is saved with a unique ID.
1828 1829 1830 1831 |
# File 'lib/aws-sdk-athena/client.rb', line 1828 def get_query_execution(params = {}, = {}) req = build_request(:get_query_execution, params) req.send_request() end |
#get_query_results(params = {}) ⇒ Types::GetQueryResultsOutput
Streams the results of a single query execution specified by ‘QueryExecutionId` from the Athena query results location in Amazon S3. For more information, see [Working with query results, recent queries, and output files] in the *Amazon Athena User Guide*. This request does not execute the query but returns results. Use StartQueryExecution to run a query.
To stream query results successfully, the IAM principal with permission to call ‘GetQueryResults` also must have permissions to the Amazon S3 `GetObject` action for the Athena query results location.
IAM principals with permission to the Amazon S3 ‘GetObject` action for the query results location are able to retrieve query results from Amazon S3 even if permission to the `GetQueryResults` action is denied. To restrict user or role access, ensure that Amazon S3 permissions to the Athena query location are denied.
[1]: docs.aws.amazon.com/athena/latest/ug/querying.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1913 1914 1915 1916 |
# File 'lib/aws-sdk-athena/client.rb', line 1913 def get_query_results(params = {}, = {}) req = build_request(:get_query_results, params) req.send_request() end |
#get_query_runtime_statistics(params = {}) ⇒ Types::GetQueryRuntimeStatisticsOutput
Returns query execution runtime statistics related to a single execution of a query if you have access to the workgroup in which the query ran. Statistics from the ‘Timeline` section of the response object are available as soon as QueryExecutionStatus$State is in a SUCCEEDED or FAILED state. The remaining non-timeline statistics in the response (like stage-level input and output row count and data size) are updated asynchronously and may not be available immediately after a query completes or, in some cases, may not be returned. The non-timeline statistics are also not included when a query has row-level filters defined in Lake Formation.
1974 1975 1976 1977 |
# File 'lib/aws-sdk-athena/client.rb', line 1974 def get_query_runtime_statistics(params = {}, = {}) req = build_request(:get_query_runtime_statistics, params) req.send_request() end |
#get_resource_dashboard(params = {}) ⇒ Types::GetResourceDashboardResponse
Gets the Live UI/Persistence UI for a session.
2002 2003 2004 2005 |
# File 'lib/aws-sdk-athena/client.rb', line 2002 def get_resource_dashboard(params = {}, = {}) req = build_request(:get_resource_dashboard, params) req.send_request() end |
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets the full details of a previously created session, including the session status and configuration.
2079 2080 2081 2082 |
# File 'lib/aws-sdk-athena/client.rb', line 2079 def get_session(params = {}, = {}) req = build_request(:get_session, params) req.send_request() end |
#get_session_endpoint(params = {}) ⇒ Types::GetSessionEndpointResponse
Gets a connection endpoint and authentication token for a given session Id.
2112 2113 2114 2115 |
# File 'lib/aws-sdk-athena/client.rb', line 2112 def get_session_endpoint(params = {}, = {}) req = build_request(:get_session_endpoint, params) req.send_request() end |
#get_session_status(params = {}) ⇒ Types::GetSessionStatusResponse
Gets the current status of a session.
2147 2148 2149 2150 |
# File 'lib/aws-sdk-athena/client.rb', line 2147 def get_session_status(params = {}, = {}) req = build_request(:get_session_status, params) req.send_request() end |
#get_table_metadata(params = {}) ⇒ Types::GetTableMetadataOutput
Returns table metadata for the specified catalog, database, and table.
2203 2204 2205 2206 |
# File 'lib/aws-sdk-athena/client.rb', line 2203 def (params = {}, = {}) req = build_request(:get_table_metadata, params) req.send_request() end |
#get_work_group(params = {}) ⇒ Types::GetWorkGroupOutput
Returns information about the workgroup with the specified name.
2279 2280 2281 2282 |
# File 'lib/aws-sdk-athena/client.rb', line 2279 def get_work_group(params = {}, = {}) req = build_request(:get_work_group, params) req.send_request() end |
#import_notebook(params = {}) ⇒ Types::ImportNotebookOutput
Imports a single ‘ipynb` file to a Spark enabled workgroup. To import the notebook, the request must specify a value for either `Payload` or `NoteBookS3LocationUri`. If neither is specified or both are specified, an `InvalidRequestException` occurs. The maximum file size that can be imported is 10 megabytes. If an `ipynb` file with the same name already exists in the workgroup, throws an error.
2341 2342 2343 2344 |
# File 'lib/aws-sdk-athena/client.rb', line 2341 def import_notebook(params = {}, = {}) req = build_request(:import_notebook, params) req.send_request() end |
#list_application_dpu_sizes(params = {}) ⇒ Types::ListApplicationDPUSizesOutput
Returns the supported DPU sizes for the supported application runtimes (for example, ‘Athena notebook version 1`).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2382 2383 2384 2385 |
# File 'lib/aws-sdk-athena/client.rb', line 2382 def list_application_dpu_sizes(params = {}, = {}) req = build_request(:list_application_dpu_sizes, params) req.send_request() end |
#list_calculation_executions(params = {}) ⇒ Types::ListCalculationExecutionsResponse
Lists the calculations that have been submitted to a session in descending order. Newer calculations are listed first; older calculations are listed later.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2456 2457 2458 2459 |
# File 'lib/aws-sdk-athena/client.rb', line 2456 def list_calculation_executions(params = {}, = {}) req = build_request(:list_calculation_executions, params) req.send_request() end |
#list_capacity_reservations(params = {}) ⇒ Types::ListCapacityReservationsOutput
Lists the capacity reservations for the current account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2503 2504 2505 2506 |
# File 'lib/aws-sdk-athena/client.rb', line 2503 def list_capacity_reservations(params = {}, = {}) req = build_request(:list_capacity_reservations, params) req.send_request() end |
#list_data_catalogs(params = {}) ⇒ Types::ListDataCatalogsOutput
Lists the data catalogs in the current Amazon Web Services account.
<note markdown=“1”> In the Athena console, data catalogs are listed as “data sources” on the **Data sources** page under the **Data source name** column.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2557 2558 2559 2560 |
# File 'lib/aws-sdk-athena/client.rb', line 2557 def list_data_catalogs(params = {}, = {}) req = build_request(:list_data_catalogs, params) req.send_request() end |
#list_databases(params = {}) ⇒ Types::ListDatabasesOutput
Lists the databases in the specified data catalog.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2610 2611 2612 2613 |
# File 'lib/aws-sdk-athena/client.rb', line 2610 def list_databases(params = {}, = {}) req = build_request(:list_databases, params) req.send_request() end |
#list_engine_versions(params = {}) ⇒ Types::ListEngineVersionsOutput
Returns a list of engine versions that are available to choose from, including the Auto option.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2652 2653 2654 2655 |
# File 'lib/aws-sdk-athena/client.rb', line 2652 def list_engine_versions(params = {}, = {}) req = build_request(:list_engine_versions, params) req.send_request() end |
#list_executors(params = {}) ⇒ Types::ListExecutorsResponse
Lists, in descending order, the executors that joined a session. Newer executors are listed first; older executors are listed later. The result can be optionally filtered by state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2723 2724 2725 2726 |
# File 'lib/aws-sdk-athena/client.rb', line 2723 def list_executors(params = {}, = {}) req = build_request(:list_executors, params) req.send_request() end |
#list_named_queries(params = {}) ⇒ Types::ListNamedQueriesOutput
Provides a list of available query IDs only for queries saved in the specified workgroup. Requires that you have access to the specified workgroup. If a workgroup is not specified, lists the saved queries for the primary workgroup.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2772 2773 2774 2775 |
# File 'lib/aws-sdk-athena/client.rb', line 2772 def list_named_queries(params = {}, = {}) req = build_request(:list_named_queries, params) req.send_request() end |
#list_notebook_metadata(params = {}) ⇒ Types::ListNotebookMetadataOutput
Displays the notebook files for the specified workgroup in paginated format.
2825 2826 2827 2828 |
# File 'lib/aws-sdk-athena/client.rb', line 2825 def (params = {}, = {}) req = build_request(:list_notebook_metadata, params) req.send_request() end |
#list_notebook_sessions(params = {}) ⇒ Types::ListNotebookSessionsResponse
Lists, in descending order, the sessions that have been created in a notebook that are in an active state like ‘CREATING`, `CREATED`, `IDLE` or `BUSY`. Newer sessions are listed first; older sessions are listed later.
2871 2872 2873 2874 |
# File 'lib/aws-sdk-athena/client.rb', line 2871 def list_notebook_sessions(params = {}, = {}) req = build_request(:list_notebook_sessions, params) req.send_request() end |
#list_prepared_statements(params = {}) ⇒ Types::ListPreparedStatementsOutput
Lists the prepared statements in the specified workgroup.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2916 2917 2918 2919 |
# File 'lib/aws-sdk-athena/client.rb', line 2916 def list_prepared_statements(params = {}, = {}) req = build_request(:list_prepared_statements, params) req.send_request() end |
#list_query_executions(params = {}) ⇒ Types::ListQueryExecutionsOutput
Provides a list of available query execution IDs for the queries in the specified workgroup. Athena keeps a query history for 45 days. If a workgroup is not specified, returns a list of query execution IDs for the primary workgroup. Requires you to have access to the workgroup in which the queries ran.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2966 2967 2968 2969 |
# File 'lib/aws-sdk-athena/client.rb', line 2966 def list_query_executions(params = {}, = {}) req = build_request(:list_query_executions, params) req.send_request() end |
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists the sessions in a workgroup that are in an active state like ‘CREATING`, `CREATED`, `IDLE`, or `BUSY`. Newer sessions are listed first; older sessions are listed later.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3046 3047 3048 3049 |
# File 'lib/aws-sdk-athena/client.rb', line 3046 def list_sessions(params = {}, = {}) req = build_request(:list_sessions, params) req.send_request() end |
#list_table_metadata(params = {}) ⇒ Types::ListTableMetadataOutput
Lists the metadata for the tables in the specified data catalog database.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3120 3121 3122 3123 |
# File 'lib/aws-sdk-athena/client.rb', line 3120 def (params = {}, = {}) req = build_request(:list_table_metadata, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with an Athena resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3165 3166 3167 3168 |
# File 'lib/aws-sdk-athena/client.rb', line 3165 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_work_groups(params = {}) ⇒ Types::ListWorkGroupsOutput
Lists available workgroups for the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3211 3212 3213 3214 |
# File 'lib/aws-sdk-athena/client.rb', line 3211 def list_work_groups(params = {}, = {}) req = build_request(:list_work_groups, params) req.send_request() end |
#put_capacity_assignment_configuration(params = {}) ⇒ Struct
Puts a new capacity assignment configuration for a specified capacity reservation. If a capacity assignment configuration already exists for the capacity reservation, replaces the existing capacity assignment configuration.
3245 3246 3247 3248 |
# File 'lib/aws-sdk-athena/client.rb', line 3245 def put_capacity_assignment_configuration(params = {}, = {}) req = build_request(:put_capacity_assignment_configuration, params) req.send_request() end |
#start_calculation_execution(params = {}) ⇒ Types::StartCalculationExecutionResponse
Submits calculations for execution within a session. You can supply the code to run as an inline code block within the request.
<note markdown=“1”> The request syntax requires the StartCalculationExecutionRequest$CodeBlock parameter or the CalculationConfiguration$CodeBlock parameter, but not both. Because CalculationConfiguration$CodeBlock is deprecated, use the StartCalculationExecutionRequest$CodeBlock parameter instead.
</note>
3313 3314 3315 3316 |
# File 'lib/aws-sdk-athena/client.rb', line 3313 def start_calculation_execution(params = {}, = {}) req = build_request(:start_calculation_execution, params) req.send_request() end |
#start_query_execution(params = {}) ⇒ Types::StartQueryExecutionOutput
Runs the SQL query statements contained in the ‘Query`. Requires you to have access to the workgroup in which the query ran. Running queries against an external catalog requires GetDataCatalog permission to the catalog. For code samples using the Amazon Web Services SDK for Java, see [Examples and Code Samples] in the *Amazon Athena User Guide*.
3448 3449 3450 3451 |
# File 'lib/aws-sdk-athena/client.rb', line 3448 def start_query_execution(params = {}, = {}) req = build_request(:start_query_execution, params) req.send_request() end |
#start_session(params = {}) ⇒ Types::StartSessionResponse
Creates a session for running calculations within a workgroup. The session is ready when it reaches an ‘IDLE` state.
3577 3578 3579 3580 |
# File 'lib/aws-sdk-athena/client.rb', line 3577 def start_session(params = {}, = {}) req = build_request(:start_session, params) req.send_request() end |
#stop_calculation_execution(params = {}) ⇒ Types::StopCalculationExecutionResponse
Requests the cancellation of a calculation. A ‘StopCalculationExecution` call on a calculation that is already in a terminal state (for example, `STOPPED`, `FAILED`, or `COMPLETED`) succeeds but has no effect.
<note markdown=“1”> Cancelling a calculation is done on a best effort basis. If a calculation cannot be cancelled, you can be charged for its completion. If you are concerned about being charged for a calculation that cannot be cancelled, consider terminating the session in which the calculation is running.
</note>
3616 3617 3618 3619 |
# File 'lib/aws-sdk-athena/client.rb', line 3616 def stop_calculation_execution(params = {}, = {}) req = build_request(:stop_calculation_execution, params) req.send_request() end |
#stop_query_execution(params = {}) ⇒ Struct
Stops a query execution. Requires you to have access to the workgroup in which the query ran.
3642 3643 3644 3645 |
# File 'lib/aws-sdk-athena/client.rb', line 3642 def stop_query_execution(params = {}, = {}) req = build_request(:stop_query_execution, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to an Athena resource. A tag is a label that you assign to a resource. Each tag consists of a key and an optional value, both of which you define. For example, you can use tags to categorize Athena workgroups, data catalogs, or capacity reservations by purpose, owner, or environment. Use a consistent set of tag keys to make it easier to search and filter the resources in your account. For best practices, see [Tagging Best Practices]. Tag keys can be from 1 to 128 UTF-8 Unicode characters, and tag values can be from 0 to 256 UTF-8 Unicode characters. Tags can use letters and numbers representable in UTF-8, and the following characters: + - = . _ : / @. Tag keys and values are case-sensitive. Tag keys must be unique per resource. If you specify more than one tag, separate them by commas.
[1]: docs.aws.amazon.com/whitepapers/latest/tagging-best-practices/tagging-best-practices.html
3690 3691 3692 3693 |
# File 'lib/aws-sdk-athena/client.rb', line 3690 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#terminate_session(params = {}) ⇒ Types::TerminateSessionResponse
Terminates an active session. A ‘TerminateSession` call on a session that is already inactive (for example, in a `FAILED`, `TERMINATED` or `TERMINATING` state) succeeds but has no effect. Calculations running in the session when `TerminateSession` is called are forcefully stopped, but may display as `FAILED` instead of `STOPPED`.
3722 3723 3724 3725 |
# File 'lib/aws-sdk-athena/client.rb', line 3722 def terminate_session(params = {}, = {}) req = build_request(:terminate_session, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an Athena resource.
3749 3750 3751 3752 |
# File 'lib/aws-sdk-athena/client.rb', line 3749 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_capacity_reservation(params = {}) ⇒ Struct
Updates the number of requested data processing units for the capacity reservation with the specified name.
3776 3777 3778 3779 |
# File 'lib/aws-sdk-athena/client.rb', line 3776 def update_capacity_reservation(params = {}, = {}) req = build_request(:update_capacity_reservation, params) req.send_request() end |
#update_data_catalog(params = {}) ⇒ Struct
Updates the data catalog that has the specified name.
3842 3843 3844 3845 |
# File 'lib/aws-sdk-athena/client.rb', line 3842 def update_data_catalog(params = {}, = {}) req = build_request(:update_data_catalog, params) req.send_request() end |
#update_named_query(params = {}) ⇒ Struct
Updates a NamedQuery object. The database or workgroup cannot be updated.
3877 3878 3879 3880 |
# File 'lib/aws-sdk-athena/client.rb', line 3877 def update_named_query(params = {}, = {}) req = build_request(:update_named_query, params) req.send_request() end |
#update_notebook(params = {}) ⇒ Struct
Updates the contents of a Spark notebook.
3923 3924 3925 3926 |
# File 'lib/aws-sdk-athena/client.rb', line 3923 def update_notebook(params = {}, = {}) req = build_request(:update_notebook, params) req.send_request() end |
#update_notebook_metadata(params = {}) ⇒ Struct
Updates the metadata for a notebook.
3960 3961 3962 3963 |
# File 'lib/aws-sdk-athena/client.rb', line 3960 def (params = {}, = {}) req = build_request(:update_notebook_metadata, params) req.send_request() end |
#update_prepared_statement(params = {}) ⇒ Struct
Updates a prepared statement.
3994 3995 3996 3997 |
# File 'lib/aws-sdk-athena/client.rb', line 3994 def update_prepared_statement(params = {}, = {}) req = build_request(:update_prepared_statement, params) req.send_request() end |
#update_work_group(params = {}) ⇒ Struct
Updates the workgroup with the specified name. The workgroup’s name cannot be changed. Only ‘ConfigurationUpdates` can be specified.
4111 4112 4113 4114 |
# File 'lib/aws-sdk-athena/client.rb', line 4111 def update_work_group(params = {}, = {}) req = build_request(:update_work_group, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4140 4141 4142 |
# File 'lib/aws-sdk-athena/client.rb', line 4140 def waiter_names [] end |