Class: Aws::Athena::Types::WorkGroupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Athena::Types::WorkGroupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-athena/types.rb
Overview
The summary information for the workgroup, which includes its name, state, description, and the date and time it was created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The workgroup creation date and time.
-
#description ⇒ String
The workgroup description.
-
#engine_version ⇒ Types::EngineVersion
The engine version setting for all queries on the workgroup.
-
#identity_center_application_arn ⇒ String
The ARN of the IAM Identity Center enabled application associated with the workgroup.
-
#name ⇒ String
The name of the workgroup.
-
#state ⇒ String
The state of the workgroup.
Instance Attribute Details
#creation_time ⇒ Time
The workgroup creation date and time.
5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 |
# File 'lib/aws-sdk-athena/types.rb', line 5741 class WorkGroupSummary < Struct.new( :name, :state, :description, :creation_time, :engine_version, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The workgroup description.
5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 |
# File 'lib/aws-sdk-athena/types.rb', line 5741 class WorkGroupSummary < Struct.new( :name, :state, :description, :creation_time, :engine_version, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ Types::EngineVersion
The engine version setting for all queries on the workgroup. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 |
# File 'lib/aws-sdk-athena/types.rb', line 5741 class WorkGroupSummary < Struct.new( :name, :state, :description, :creation_time, :engine_version, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#identity_center_application_arn ⇒ String
The ARN of the IAM Identity Center enabled application associated with the workgroup.
5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 |
# File 'lib/aws-sdk-athena/types.rb', line 5741 class WorkGroupSummary < Struct.new( :name, :state, :description, :creation_time, :engine_version, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workgroup.
5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 |
# File 'lib/aws-sdk-athena/types.rb', line 5741 class WorkGroupSummary < Struct.new( :name, :state, :description, :creation_time, :engine_version, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the workgroup.
5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 |
# File 'lib/aws-sdk-athena/types.rb', line 5741 class WorkGroupSummary < Struct.new( :name, :state, :description, :creation_time, :engine_version, :identity_center_application_arn) SENSITIVE = [] include Aws::Structure end |